# Generated by roxygen2: do not edit by hand

export("%>%")
export(as.yearmon)
export(as.yearqtr)
export(dyAnnotation)
export(dyAxis)
export(dyBarChart)
export(dyBarSeries)
export(dyCSS)
export(dyCallbacks)
export(dyCandlestick)
export(dyCandlestickGroup)
export(dyCrosshair)
export(dyDataHandler)
export(dyDependency)
export(dyErrorFill)
export(dyEvent)
export(dyFilledLine)
export(dyGroup)
export(dyHighlight)
export(dyLegend)
export(dyLimit)
export(dyMultiColumn)
export(dyMultiColumnGroup)
export(dyOptions)
export(dyPlotter)
export(dyPlugin)
export(dyRangeSelector)
export(dyRebase)
export(dyRibbon)
export(dyRoller)
export(dySeries)
export(dySeriesData)
export(dyShading)
export(dyShadow)
export(dyStackedBarChart)
export(dyStackedBarGroup)
export(dyStackedLineGroup)
export(dyStackedRibbonGroup)
export(dyStemSeries)
export(dyUnzoom)
export(dygraph)
export(dygraphOutput)
export(renderDygraph)
importFrom(grDevices,rgb)
importFrom(htmltools,htmlDependency)
importFrom(htmlwidgets,JS)
importFrom(magrittr,"%>%")
importFrom(stats,end)
importFrom(stats,start)
importFrom(zoo,as.yearmon)
importFrom(zoo,as.yearqtr)
