#' dygraph exported operators and S3 methods
#' 
#' The following functions are imported and then re-exported
#' from the dygraphs package to avoid listing the magrittr and
#' zoo packages as Depends of dygraphs.
#' 
#' @name dygraphs-exports
NULL

#' @importFrom magrittr %>%
#' @name %>%
#' @export
#' @rdname dygraphs-exports
NULL

#' @importFrom zoo as.yearmon
#' @name as.yearmon
#' @export as.yearmon
#' @rdname dygraphs-exports
NULL

#' @importFrom zoo as.yearqtr
#' @name as.yearqtr
#' @export as.yearqtr
#' @rdname dygraphs-exports 
NULL
