Filing a bug report? Please include the following:

1. Link to a page which demonstrates the problem, preferably a jsfiddle (use http://dygraphs.com/fiddle as a template)
2. Browser and Operating System that exhibit the problem
3. Version of dygraphs that you're using

It also helps if you include the non-compacted version of the JS on your
page. For instance, instead of doing this:

```html
<script type="text/javascript" src="dygraph.min.js"></script>
```

do this:

```html
<script type="text/javascript" src="dygraph.js"></script>
```

This makes error messages and debugging simpler. The jsfiddle does this automatically.
